@@ -1,6 +1,6 @@
 package SMIL::XMLBase;
 
-$VERSION = "0.701";
+$VERSION = "0.72";
 
 $ZERO_STRING = "ZERO_STRING";
 $TRUE = 'true';
@@ -45,6 +45,25 @@ sub new {
     return $self;
 }
 
+sub setPrivate {
+
+   my $self = shift;
+   my $key = shift;
+   my $value = shift;
+
+   if( $key and $value ) {
+							$self->{_private} = {} if !$self->{_private};
+							$self->{_private}->{ $key } = $value;
+			}
+}
+
+sub getPrivate {
+				my $self = shift;
+				my $key = shift;
+				
+				return( $self->{_private}->{ $key } ); # if $self->{_private};
+}
+
 sub setTag {
     my $self = shift;
     my $tag = shift;
@@ -52,9 +71,9 @@ sub setTag {
 }
 
 sub setFavorite {
-	my $self = shift;
-	my $favorite = shift;
-	$self->{_favorite} = $favorite;
+				my $self = shift;
+				my $favorite = shift;
+				$self->{_favorite} = $favorite;
 }
 
 sub getTag {
