@@ -1,6 +1,6 @@
 package Smil;
 
-$VERSION = "0.701";
+$VERSION = "0.72";
 
 use Carp;
 use SMIL::XMLBase;
@@ -17,26 +17,61 @@ my $body = "body";
 my @timelineStack;
 my $smil;
 my $file = "file";
+my $INLINE = 'inline';
 
+my $CV_SYSTEM_COMPONENT = "cv:systemComponent";
+my @RP_SYSTEM_REQUIRED_ATTRIBUTE = ( "system-required" => "cv" );
+
+my $RN_EXTENSIONS = 'rn-extensions';
+my $RN_SHORT = 'rn';
 my $QT_EXTENSIONS = 'qt-extensions';
 my $QT_SHORT = 'qt';
 my $QT_NS_URL = "http://www.apple.com/quicktime/resources/smilextensions";
 my $QT_NS = "xmlns:qt";
 
+my $VERSION_COMPATIBLE = 'version';
+my $PLAYER_COMPATIBLE = 'player';
+my $RP_COMPATIBLE = 'rp';
+my $QT_COMPATIBLE = 'qt';
+
 my $QT_AUTOPLAY = "qt:autoplay";
 my $QT_CHAPTER_MODE = "qt:chapter-mode";
 my $QT_IMMEDIATE_INSTANTIATION = "qt:immediate-instantiation";
 my $QT_NEXT = "qt:next";
 my $QT_TIME_SLIDER = "qt:time-slider";
 
-my $RN_CV = "xmlns:cv";
+my $RN_NS = "xmlns:cv";
+my $RN_NS_URL = "http://features.real.com/systemComponent";
 
-my @smilAttributes = ( $RN_CV,
-$QT_AUTOPLAY,
-$QT_CHAPTER_MODE,
-$QT_IMMEDIATE_INSTANTIATION,
-$QT_NEXT,
-$QT_TIME_SLIDER );
+my %earliestAttribute = ( 'inline' => 7 );
+
+my @RP_VERSION_MAPPING = ( "",  		# 0
+																													"", 		# 1, unsupported
+																													"", 		# 2, unsupported
+																													"", 		# 3, unsupported
+																													"", 		# 4, unsupported
+																													"", 		# 5, unsupported
+																													"", 		# 6, no switch allowed
+																													
+																													# 7, Gold Player 7
+																													"http://features.real.com/?feature;player=6.0.7.380", 		
+																													
+																													# 8, Gold Player 8
+																													"http://features.real.com/?feature;player=6.0.9.450",
+																													);
+
+my %VERSION_MAPPING = ( $RP_COMPATIBLE => \@RP_VERSION_MAPPING );
+
+my %RP_FEATURE_VERSION_MAPPING = ( 'inline' => 7, 'newwindow' => 7 );
+
+my %FEATURE_VERSION_MAPPING = ( $RP_COMPATIBLE => \%RP_FEATURE_VERSION_MAPPING );
+
+my @smilAttributes = ( $RN_NS,
+																							$QT_AUTOPLAY,
+																							$QT_CHAPTER_MODE,
+																							$QT_IMMEDIATE_INSTANTIATION,
+																							$QT_NEXT,
+																							$QT_TIME_SLIDER );
 
 sub init {
     my $self = shift;
@@ -48,12 +83,12 @@ sub init {
 
     if( $hash{ $QT_SHORT } or 
 	$hash{ $QT_EXTENSIONS } ) {
-         $smilAttrs{ $QT_NS } = $QT_NS_URL;
-	$favorite = $QT_NS;
+	$self->useQtExtensions;
     }
 
-    if( $hash{ RN_CV } ) {
-	
+    if( $hash{ $RN_EXTENSIONS } or 
+	$hash{ $RN_SHORT } ) {
+	$self->useRnExtensions;	
     }
 
     $self->setAttributes( %smilAttrs );
@@ -96,6 +131,14 @@ sub useQtTimeSlider {
 	$self->useQtExtensions;
 }
 
+sub useRnExtensions {
+	my $self = shift;
+	my $version = shift;
+
+	$self->setAttribute( $RN_NS => $RN_NS_URL );
+	$self->setFavorite( $RN_NS );
+}
+
 sub useQtExtensions {
 	my $self = shift;
 	$self->setAttribute( $QT_NS => $QT_NS_URL );
@@ -179,13 +222,124 @@ sub hasQtExtensions {
 
 sub addMedia {
     my $self = shift;
-
+				
     # Check for QT extensions, and add if necessary
     if( $self->hasQtExtensions( @_ ) ) {
-	$self->useQtExtensions;
+								$self->useQtExtensions;
     }
+				
+    # Make sure that if we are adding inline that we
+    # add the RP version checking code in case
+    # we need to add a switch because we are authoring
+    # for all players...
+    if( &isInlined( @_ ) and $self->authoringBackwardsCompatible() ) {
+								$self->useRnExtensions;
+								# Add a switch statement of the possible entries here.
+								$self->addBackwardsCompatibleSwitch( 'inline', @_ );
+    }
+    else {
+								$self->getContentObjectByName( $body )->addMedia( @_ );
+    }
+}
 
-    $self->getContentObjectByName( $body )->addMedia( @_ );
+sub getEarliestSupportedVersion {
+
+   my $type = shift;
+			my $feature = shift;
+
+   print STDERR "Only RealPlayer is supported as backwards compatible type so far.: $type\n" 
+							unless $type eq $RP_COMPATIBLE;
+
+   return( $FEATURE_VERSION_MAPPING{ $type }->{ $feature } );  # $RP_VERSION_COMPONENT );
+
+}
+
+sub getSupportedVersionAttribute {
+
+   my $version = shift;
+   my $player = shift;
+
+   print STDERR "Only RealPlayer supported as backwards compatible type so far.: $player\n" 
+							unless $player eq $RP_COMPATIBLE;
+			
+   return( $CV_SYSTEM_COMPONENT, $VERSION_MAPPING{ $player }->[ $version ] );
+			
+}
+
+sub getEarliestVersionForAttribute {
+				my $attribute = shift;
+				return $earliestAttribute{ $attribute };
+}
+
+sub addBackwardsCompatibleSwitch {
+				
+    my $self = shift;
+				
+				# Check for this 'feature' when adding switch code
+				my $feature = shift;
+    my @medias = ();
+				
+    my $earliestVersion = &getEarliestVersionForAttribute( $attribute ); 
+				# $self->getPrivate( $VERSION_COMPATIBLE ); # Don't really need this right now..
+    my $playerType = $self->getPrivate( $PLAYER_COMPATIBLE );
+				
+				# Need a attribute list with the attribute we are switching on
+				# and another without.
+				my %withSwitchingAttribute = @_;
+				
+				# Remove the attribute
+				my %withoutSwitchingAttribute = @_;
+				undef( $withoutSwitchingAttribute{ $attribute } );
+				
+    # Create a different media object for each of the versions
+    # to support.  Make sure to go backwards since switch uses first
+    # match
+				my $supportedIndex = &getEarliestSupportedVersion( $playerType, $feature );
+
+				my @attributes = ( %withSwitchingAttribute, 
+																							( @RP_SYSTEM_REQUIRED_ATTRIBUTE, 
+																									&getSupportedVersionAttribute( $supportedIndex, 	
+																																																								$self->getPrivate( $PLAYER_COMPATIBLE ) ) ) );
+				# attributes, and push it on the stack
+				push @medias, SMIL::MediaFactory::getMediaObject( @attributes );
+				
+				# Now, add the one without the attribute
+				push @medias, SMIL::MediaFactory::getMediaObject( %withoutSwitchingAttribute );
+				
+				# Create the different medias 
+				$self->addSwitchedMedia( 'switch' => 'system-required',
+																													medias => [ \@medias ] );
+}
+
+sub authoringBackwardsCompatible {
+				my $self = shift;
+				return( $self->getPrivate( $VERSION_COMPATIBLE ) and $self->getPrivate( $PLAYER_COMPATIBLE ) );
+}
+
+sub setBackwardsCompatible {
+				
+				my $self = shift;
+				
+				# Get a version number, if they gave it to us.
+				my %args = @_;
+				
+				my $version = $args{ $VERSION_COMPATIBLE };
+				
+				my $player = $args{ $PLAYER_COMPATIBLE };
+				
+				# Only do it for RN players right now...
+				if( $player eq $RP_COMPATIBLE ) {
+								$self->setPrivate( $PLAYER_COMPATIBLE => $player );
+								$self->setPrivate( $VERSION_COMPATIBLE => $version );
+				}
+				else {
+								print STDERR "Backwards compatible only supported for RealPlayer so far.";
+				}
+}
+
+sub isInlined {
+				my %args = @_;  
+				return defined( $args{ $INLINE } );
 }
 
 sub addCode {
